####################
  SOAP Usage
####################

This contains exampes of how to use the soap package

.. toctree::
    :maxdepth: 2

    run_soap_search.ipynb
    generate_lookup_table.ipynb
    generate_cw_signal.ipynb
    load_sft_from_file.ipynb
    write_sft_to_file.ipynb
